# PyDS CLI
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-4-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

Helping you manage your data science projects _sanely_.

[![asciicast](https://asciinema.org/a/quuvL2LCafmRfpFAbQLREwpke.svg)](https://asciinema.org/a/quuvL2LCafmRfpFAbQLREwpke)

## Requirements

- [Anaconda]/[Miniconda]/[Miniforge]/[Mambaforge] (Mambaforge recommended!)
- `git` on your PATH

[Anaconda]: https://www.anaconda.com

[Miniconda]: https://docs.conda.io/en/latest/miniconda.html

[Miniforge]: https://github.com/conda-forge/miniforge

[Mambaforge]: https://github.com/conda-forge/miniforge#mambaforge

## Quickstart

We're in development! Install directly from `git` into your base Anaconda environment.

```python
pip install git+https://github.com/ericmjl/pyds-cli
```

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://ericmjl.github.io/"><img src="https://avatars.githubusercontent.com/u/2631566?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Eric Ma</b></sub></a><br /><a href="https://github.com/ericmjl/pyds-cli/commits?author=ericmjl" title="Code">💻</a> <a href="#infra-ericmjl" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="https://github.com/ericmjl/pyds-cli/commits?author=ericmjl" title="Tests">⚠️</a> <a href="#tutorial-ericmjl" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://www.loganthomas.dev"><img src="https://avatars.githubusercontent.com/u/24984410?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Logan Thomas</b></sub></a><br /><a href="#ideas-loganthomas" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="http://giessel.com"><img src="https://avatars.githubusercontent.com/u/1160997?v=4?s=100" width="100px;" alt=""/><br /><sub><b>andrew giessel</b></sub></a><br /><a href="#ideas-andrewgiessel" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/amenda860111"><img src="https://avatars.githubusercontent.com/u/32970102?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Amanda</b></sub></a><br /><a href="#ideas-amenda860111" title="Ideas, Planning, & Feedback">🤔</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
